qcacld-3.0: Remove duplicate tSirMsgQ structure from MAC module

After control path scheduler componentization every legacy module
is supposed to use common converged scheduler message types and APIs.
Remove duplicate tSirMsgQ message types in mac and use converged scheduler
message queue APIs.

Change-Id: If47df18043f8127a20a72562bf45afe37dabca72
CRs-Fixed: 1114378
diff --git a/core/mac/src/cfg/cfg_api.c b/core/mac/src/cfg/cfg_api.c
index 2d34785..9aed4ca 100644
--- a/core/mac/src/cfg/cfg_api.c
+++ b/core/mac/src/cfg/cfg_api.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -913,7 +913,7 @@
 static void notify(tpAniSirGlobal pMac, uint16_t cfgId, uint32_t ntfMask)
 {
 
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	mmhMsg.type = SIR_CFG_PARAM_UPDATE_IND;
 	mmhMsg.bodyval = (uint32_t) cfgId;
diff --git a/core/mac/src/cfg/cfg_proc_msg.c b/core/mac/src/cfg/cfg_proc_msg.c
index 8be379c..e195d52 100644
--- a/core/mac/src/cfg/cfg_proc_msg.c
+++ b/core/mac/src/cfg/cfg_proc_msg.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -1469,7 +1469,7 @@
 	uint8_t pStr[CFG_MAX_STR_LEN];
 	tpCfgBinHdr pHdr;
 	uint32_t logLevel;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	/* First Dword must contain the AP or STA magic dword */
 	PELOGW(cfg_log(pMac, LOGW, FL("CFG size %d bytes MAGIC dword is 0x%x"),
diff --git a/core/mac/src/cfg/cfg_send_msg.c b/core/mac/src/cfg/cfg_send_msg.c
index a50652c..d30fa24 100644
--- a/core/mac/src/cfg/cfg_send_msg.c
+++ b/core/mac/src/cfg/cfg_send_msg.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2014-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012, 2014-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -75,7 +75,7 @@
 		  uint32_t *pData)
 {
 	uint32_t *pMsg, *pEnd;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	/* sanity */
 	if ((paramNum > 0) && (NULL == pParamList)) {
diff --git a/core/mac/src/include/sir_params.h b/core/mac/src/include/sir_params.h
index a8d27ec..f83a9fe 100644
--- a/core/mac/src/include/sir_params.h
+++ b/core/mac/src/include/sir_params.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -112,35 +112,6 @@
 	eSIR_LINK_DOWN_STATE = 5,
 } tSirLinkState;
 
-/* / Message queue structure used across Sirius project. */
-/* / NOTE: this structure should be multiples of a word size (4bytes) */
-/* / as this is used in tx_queue where it expects to be multiples of 4 bytes. */
-typedef struct sSirMsgQ {
-	uint16_t type;
-	/*
-	 * This field can be used as sequence number/dialog token for matching
-	 * requests and responses.
-	 */
-	uint16_t reserved;
-	/**
-	 * Based on the type either a bodyptr pointer into
-	 * memory or bodyval as a 32 bit data is used.
-	 * bodyptr: is always a freeable pointer, one should always
-	 * make sure that bodyptr is always freeable.
-	 *
-	 * Messages should use either bodyptr or bodyval; not both !!!.
-	 */
-	void *bodyptr;
-	uint32_t bodyval;
-
-	/*
-	 * Some messages provide a callback function.  The function signature
-	 * must be agreed upon between the two entities exchanging the message
-	 */
-	void *callback;
-
-} tSirMsgQ, *tpSirMsgQ;
-
 /* / Mailbox Message Structure Define */
 typedef struct sSirMbMsg {
 	uint16_t type;
diff --git a/core/mac/src/pe/include/lim_admit_control.h b/core/mac/src/pe/include/lim_admit_control.h
index 90eae86..5e364f8 100644
--- a/core/mac/src/pe/include/lim_admit_control.h
+++ b/core/mac/src/pe/include/lim_admit_control.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2012, 2014-2015 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2012, 2014-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -101,6 +101,6 @@
 				      uint8_t tspecIdx,
 				      tSirDeltsReqInfo delts,
 				      uint8_t sessionId, uint8_t *bssId);
-void lim_process_hal_add_ts_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsg);
+void lim_process_hal_add_ts_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
 
 #endif
diff --git a/core/mac/src/pe/include/lim_api.h b/core/mac/src/pe/include/lim_api.h
index f59fcf8..21c47cf 100644
--- a/core/mac/src/pe/include/lim_api.h
+++ b/core/mac/src/pe/include/lim_api.h
@@ -121,8 +121,8 @@
 tSirRetStatus lim_start(tpAniSirGlobal pMac);
 tSirRetStatus pe_start(tpAniSirGlobal pMac);
 void pe_stop(tpAniSirGlobal pMac);
-tSirRetStatus pe_post_msg_api(tpAniSirGlobal pMac, tSirMsgQ *pMsg);
-tSirRetStatus peProcessMsg(tpAniSirGlobal pMac, tSirMsgQ *limMsg);
+tSirRetStatus pe_post_msg_api(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
+tSirRetStatus peProcessMsg(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
 
 /**
  * pe_register_mgmt_rx_frm_callback() - registers callback for receiving
@@ -166,14 +166,14 @@
  */
 extern void lim_cleanup(tpAniSirGlobal);
 /* / Function to post messages to LIM thread */
-extern uint32_t lim_post_msg_api(tpAniSirGlobal, tSirMsgQ *);
-uint32_t lim_post_msg_high_priority(tpAniSirGlobal mac, tSirMsgQ *msg);
+extern uint32_t lim_post_msg_api(tpAniSirGlobal, struct scheduler_msg *);
+uint32_t lim_post_msg_high_priority(tpAniSirGlobal mac, struct scheduler_msg *msg);
 
 /**
  * Function to process messages posted to LIM thread
  * and dispatch to various sub modules within LIM module.
  */
-extern void lim_message_processor(tpAniSirGlobal, tpSirMsgQ);
+extern void lim_message_processor(tpAniSirGlobal, struct scheduler_msg *);
 /**
  * Function to check the LIM state if system is in Scan/Learn state.
  */
@@ -229,7 +229,7 @@
 				    tpUpdateBeaconParams pBeaconParams,
 				    tpPESession);
 
-void lim_ps_offload_handle_missed_beacon_ind(tpAniSirGlobal pMac, tpSirMsgQ pMsg);
+void lim_ps_offload_handle_missed_beacon_ind(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 void lim_send_heart_beat_timeout_ind(tpAniSirGlobal pMac, tpPESession psessionEntry);
 tMgmtFrmDropReason lim_is_pkt_candidate_for_drop(tpAniSirGlobal pMac,
 						 uint8_t *pRxPacketInfo,
@@ -300,7 +300,7 @@
    \return  uint32_t - TX_SUCCESS for success.
 
    --------------------------------------------------------------------------*/
-tSirRetStatus pe_process_messages(tpAniSirGlobal pMac, tSirMsgQ *pMsg);
+tSirRetStatus pe_process_messages(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 QDF_STATUS pe_mc_process_handler(struct scheduler_msg *msg);
 
 /** -------------------------------------------------------------
@@ -310,10 +310,10 @@
  \      This happens when there are messages pending in the PE
  \      queue when system is being stopped and reset.
    \param   tpAniSirGlobal pMac
-   \param   tSirMsgQ       pMsg
+   \param   struct scheduler_msg       pMsg
    \return none
    -----------------------------------------------------------------*/
-void pe_free_msg(tpAniSirGlobal pMac, tSirMsgQ *pMsg);
+void pe_free_msg(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 
 /*--------------------------------------------------------------------------
 
diff --git a/core/mac/src/pe/include/lim_ft.h b/core/mac/src/pe/include/lim_ft.h
index e475113..244e456 100644
--- a/core/mac/src/pe/include/lim_ft.h
+++ b/core/mac/src/pe/include/lim_ft.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -48,7 +48,7 @@
 #ifdef WLAN_FEATURE_HOST_ROAM
 void lim_ft_cleanup_pre_auth_info(tpAniSirGlobal pMac,
 		tpPESession psessionEntry);
-int lim_process_ft_pre_auth_req(tpAniSirGlobal pMac, tpSirMsgQ pMsg);
+int lim_process_ft_pre_auth_req(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 void lim_process_ft_preauth_rsp_timeout(tpAniSirGlobal pMac);
 void lim_process_mlm_ft_reassoc_req(tpAniSirGlobal pMac, uint32_t *pMsgBuf,
 		tpPESession psessionEntry);
@@ -64,7 +64,7 @@
 		tpPESession psessionEntry);
 void lim_process_mlm_reassoc_cnf(tpAniSirGlobal mac_ctx, uint32_t *msg);
 void lim_process_sta_mlm_add_bss_rsp_ft(tpAniSirGlobal pMac,
-		tpSirMsgQ limMsgQ, tpPESession psessionEntry);
+		struct scheduler_msg *limMsgQ, tpPESession psessionEntry);
 void lim_process_mlm_reassoc_req(tpAniSirGlobal mac_ctx, uint32_t *msg);
 void lim_preauth_scan_event_handler(tpAniSirGlobal mac_ctx,
 				enum sir_scan_event_type event,
@@ -89,7 +89,7 @@
 		uint32_t *msg)
 {}
 static inline void lim_process_sta_mlm_add_bss_rsp_ft(tpAniSirGlobal pMac,
-		tpSirMsgQ limMsgQ, tpPESession psessionEntry)
+		struct scheduler_msg *limMsgQ, tpPESession psessionEntry)
 {}
 static inline void lim_process_mlm_reassoc_req(tpAniSirGlobal mac_ctx,
 		uint32_t *msg)
@@ -99,7 +99,7 @@
 		uint8_t session_id, uint32_t scan_id)
 {}
 static inline int lim_process_ft_pre_auth_req(tpAniSirGlobal pMac,
-		tpSirMsgQ pMsg)
+		struct scheduler_msg *pMsg)
 {
 	return 0;
 }
@@ -130,6 +130,6 @@
 bool lim_process_ft_update_key(tpAniSirGlobal pMac, uint32_t *pMsgBuf);
 tSirRetStatus lim_process_ft_aggr_qos_req(tpAniSirGlobal pMac,
 		uint32_t *pMsgBuf);
-void lim_process_ft_aggr_qo_s_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsg);
+void lim_process_ft_aggr_qo_s_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
 void lim_ft_cleanup_all_ft_sessions(tpAniSirGlobal pMac);
 #endif /* __LIMFT_H__ */
diff --git a/core/mac/src/pe/include/lim_global.h b/core/mac/src/pe/include/lim_global.h
index be0efaf..14a0567 100644
--- a/core/mac/src/pe/include/lim_global.h
+++ b/core/mac/src/pe/include/lim_global.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -344,7 +344,7 @@
 
 /* Structure definition to hold deferred messages queue parameters */
 typedef struct sLimDeferredMsgQParams {
-	tSirMsgQ deferredQueue[MAX_DEFERRED_QUEUE_LEN];
+	struct scheduler_msg deferredQueue[MAX_DEFERRED_QUEUE_LEN];
 	uint16_t size;
 	uint16_t read;
 	uint16_t write;
diff --git a/core/mac/src/pe/include/rrm_api.h b/core/mac/src/pe/include/rrm_api.h
index 7f599c3..9002227 100644
--- a/core/mac/src/pe/include/rrm_api.h
+++ b/core/mac/src/pe/include/rrm_api.h
@@ -89,7 +89,7 @@
 extern void rrm_update_start_tsf(tpAniSirGlobal pMac, uint32_t startTSF[2]);
 
 extern tSirRetStatus rrm_set_max_tx_power_rsp(tpAniSirGlobal pMac,
-					      tpSirMsgQ limMsgQ);
+					      struct scheduler_msg *limMsgQ);
 
 extern tSirRetStatus
 rrm_process_neighbor_report_req(tpAniSirGlobal pMac,
diff --git a/core/mac/src/pe/include/sch_api.h b/core/mac/src/pe/include/sch_api.h
index 04db805..fbe6172 100644
--- a/core/mac/src/pe/include/sch_api.h
+++ b/core/mac/src/pe/include/sch_api.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2015 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2015, 2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -74,13 +74,13 @@
 extern void sch_initializeCfEndTemplate(tpAniSirGlobal pMac);
 
 /* / Process the scheduler messages */
-extern void sch_process_message(tpAniSirGlobal pMac, tpSirMsgQ pSchMsg);
+extern void sch_process_message(tpAniSirGlobal pMac, struct scheduler_msg *pSchMsg);
 
 /* / The beacon Indication handler function */
-extern void sch_process_pre_beacon_ind(tpAniSirGlobal pMac, tpSirMsgQ limMsg);
+extern void sch_process_pre_beacon_ind(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
 
 /* / Post a message to the scheduler message queue */
-extern tSirRetStatus sch_post_message(tpAniSirGlobal pMac, tpSirMsgQ pMsg);
+extern tSirRetStatus sch_post_message(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 
 extern void sch_beacon_process(tpAniSirGlobal pMac, uint8_t *pRxPacketInfo,
 			       tpPESession psessionEntry);
diff --git a/core/mac/src/pe/lim/lim_admit_control.c b/core/mac/src/pe/lim/lim_admit_control.c
index 7c361f3..254c4c7 100644
--- a/core/mac/src/pe/lim/lim_admit_control.c
+++ b/core/mac/src/pe/lim/lim_admit_control.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -916,7 +916,7 @@
 			uint8_t tspecIdx, tSirMacTspecIE tspecIE, uint8_t sessionId)
 #endif
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAddTsParams pAddTsParam;
 
 	tpPESession psessionEntry = pe_find_session_by_session_id(pMac, sessionId);
@@ -983,7 +983,7 @@
 			uint8_t tspecIdx,
 			tSirDeltsReqInfo delts, uint8_t sessionId, uint8_t *bssId)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpDelTsParams pDelTsParam;
 	tpPESession psessionEntry = NULL;
 
@@ -1047,9 +1047,9 @@
  \       then send back SME_ADDTS_RSP.
  \
    \param  tpAniSirGlobal  pMac
-   \param  tpSirMsgQ   limMsg
+   \param  struct scheduler_msg *limMsg
    -------------------------------------------------------------*/
-void lim_process_hal_add_ts_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsg)
+void lim_process_hal_add_ts_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsg)
 {
 	tpAddTsParams pAddTsRspMsg = NULL;
 	tpDphHashNode pSta = NULL;
diff --git a/core/mac/src/pe/lim/lim_api.c b/core/mac/src/pe/lim/lim_api.c
index 8d08576..3dcf16a 100644
--- a/core/mac/src/pe/lim/lim_api.c
+++ b/core/mac/src/pe/lim/lim_api.c
@@ -880,10 +880,10 @@
  \      This happens when there are messages pending in the PE
  \      queue when system is being stopped and reset.
    \param   tpAniSirGlobal pMac
-   \param   tSirMsgQ       pMsg
+   \param   struct scheduler_msg       pMsg
    \return none
    -----------------------------------------------------------------*/
-void pe_free_msg(tpAniSirGlobal pMac, tSirMsgQ *pMsg)
+void pe_free_msg(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	if (pMsg != NULL) {
 		if (NULL != pMsg->bodyptr) {
@@ -922,7 +922,7 @@
  * @return None
  */
 
-uint32_t lim_post_msg_api(tpAniSirGlobal pMac, tSirMsgQ *pMsg)
+uint32_t lim_post_msg_api(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	return scheduler_post_msg(QDF_MODULE_ID_PE, (struct scheduler_msg *) pMsg);
 
@@ -937,7 +937,7 @@
  *
  * Return: returns value returned by vos_mq_post_message_by_priority
  */
-uint32_t lim_post_msg_high_priority(tpAniSirGlobal mac, tSirMsgQ *msg)
+uint32_t lim_post_msg_high_priority(tpAniSirGlobal mac, struct scheduler_msg *msg)
 {
 	return scheduler_post_msg_by_priority(QDF_MODULE_ID_PE,
 					       (struct scheduler_msg *)msg, HIGH_PRIORITY);
@@ -958,7 +958,7 @@
 
    --------------------------------------------------------------------------*/
 
-tSirRetStatus pe_post_msg_api(tpAniSirGlobal pMac, tSirMsgQ *pMsg)
+tSirRetStatus pe_post_msg_api(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	return (tSirRetStatus) lim_post_msg_api(pMac, pMsg);
 }
@@ -976,7 +976,7 @@
 
    --------------------------------------------------------------------------*/
 
-tSirRetStatus pe_process_messages(tpAniSirGlobal pMac, tSirMsgQ *pMsg)
+tSirRetStatus pe_process_messages(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	if (ANI_DRIVER_TYPE(pMac) == eDRIVER_TYPE_MFG) {
 		return eSIR_SUCCESS;
@@ -1000,7 +1000,7 @@
 	if (mac_ctx == NULL)
 		return QDF_STATUS_E_FAILURE;
 
-	status = pe_process_messages((tHalHandle)mac_ctx, (tSirMsgQ *)msg);
+	status = pe_process_messages((tHalHandle)mac_ctx, (struct scheduler_msg *)msg);
 	if (status == eSIR_SUCCESS)
 		return QDF_STATUS_SUCCESS;
 
@@ -1028,7 +1028,7 @@
 {
 	tpAniSirGlobal pMac;
 	tpSirMacMgmtHdr mHdr;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	cds_pkt_t *pVosPkt;
 	QDF_STATUS qdf_status;
 	uint8_t *pRxPacketInfo;
@@ -1705,7 +1705,7 @@
 void lim_send_heart_beat_timeout_ind(tpAniSirGlobal pMac, tpPESession psessionEntry)
 {
 	uint32_t statusCode;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	/* Prepare and post message to LIM Message Queue */
 	msg.type = (uint16_t) SIR_LIM_HEART_BEAT_TIMEOUT;
@@ -1732,7 +1732,7 @@
  *
  * Return: void
  */
-void lim_ps_offload_handle_missed_beacon_ind(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+void lim_ps_offload_handle_missed_beacon_ind(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	tpSirSmeMissedBeaconInd pSirMissedBeaconInd =
 		(tpSirSmeMissedBeaconInd) pMsg->bodyptr;
@@ -2242,7 +2242,7 @@
 				int32_t rssi)
 {
 	struct sir_lost_link_info *lost_link_info;
-	tSirMsgQ mmh_msg;
+	struct scheduler_msg mmh_msg;
 
 	if ((NULL == mac) || (NULL == session)) {
 		QDF_TRACE(QDF_MODULE_ID_PE, QDF_TRACE_LEVEL_ERROR,
diff --git a/core/mac/src/pe/lim/lim_assoc_utils.c b/core/mac/src/pe/lim/lim_assoc_utils.c
index 19f84ec..fd4e593 100644
--- a/core/mac/src/pe/lim/lim_assoc_utils.c
+++ b/core/mac/src/pe/lim/lim_assoc_utils.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -2126,7 +2126,7 @@
 	tpDphHashNode sta_ds, uint8_t update_entry, tpPESession session_entry)
 {
 	tpAddStaParams add_sta_params = NULL;
-	tSirMsgQ msg_q;
+	struct scheduler_msg msg_q;
 	tSirRetStatus ret_code = eSIR_SUCCESS;
 	tSirMacAddr sta_mac, *sta_Addr;
 	uint8_t i, nw_type_11b = 0;
@@ -2546,7 +2546,7 @@
 	    tpDphHashNode pStaDs, bool fRespReqd, tpPESession psessionEntry)
 {
 	tpDeleteStaParams pDelStaParams = NULL;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode = eSIR_SUCCESS;
 
 	pDelStaParams = qdf_mem_malloc(sizeof(tDeleteStaParams));
@@ -2669,7 +2669,7 @@
 		 tpPESession psessionEntry)
 {
 	tpAddStaParams pAddStaParams = NULL;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode = eSIR_SUCCESS;
 	tSirMacAddr staMac;
 	uint32_t listenInterval = WNI_CFG_LISTEN_INTERVAL_STADEF;
@@ -3347,7 +3347,7 @@
 	    tpPESession psessionEntry)
 {
 	tpDeleteBssParams pDelBssParams = NULL;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode = eSIR_SUCCESS;
 
 	pDelBssParams = qdf_mem_malloc(sizeof(tDeleteBssParams));
@@ -3541,7 +3541,7 @@
 				   tpSirBssDescription bssDescription,
 				   uint8_t updateEntry, tpPESession psessionEntry)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpAddBssParams pAddBssParams = NULL;
 	uint32_t retCode;
 	tpDphHashNode pStaDs = NULL;
@@ -4071,7 +4071,7 @@
 tSirRetStatus lim_sta_send_add_bss_pre_assoc(tpAniSirGlobal pMac, uint8_t updateEntry,
 					     tpPESession psessionEntry)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpAddBssParams pAddBssParams = NULL;
 	uint32_t retCode;
 	tSchBeaconStruct *pBeaconStruct;
@@ -4786,7 +4786,7 @@
 					     uint16_t sessionId,
 					     tpPESession psessionEntry)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirSmeUnprotMgmtFrameInd *pSirSmeMgmtFrame = NULL;
 	uint16_t length;
 
@@ -4829,7 +4829,7 @@
 void lim_send_sme_tsm_ie_ind(tpAniSirGlobal pMac, tpPESession psessionEntry,
 			     uint8_t tid, uint8_t state, uint16_t measInterval)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tpSirSmeTsmIEInd pSirSmeTsmIeInd = NULL;
 
 	if (!pMac || !psessionEntry)
diff --git a/core/mac/src/pe/lim/lim_ft.c b/core/mac/src/pe/lim/lim_ft.c
index 80bfec8..91062c1 100644
--- a/core/mac/src/pe/lim/lim_ft.c
+++ b/core/mac/src/pe/lim/lim_ft.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -874,7 +874,7 @@
 	return;
 }
 
-void lim_process_ft_aggr_qo_s_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsg)
+void lim_process_ft_aggr_qo_s_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsg)
 {
 	tpAggrAddTsParams pAggrQosRspMsg = NULL;
 	tAddTsParams addTsParam = { 0 };
@@ -940,7 +940,7 @@
 
 tSirRetStatus lim_process_ft_aggr_qos_req(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirAggrQosReq *aggrQosReq = (tSirAggrQosReq *) pMsgBuf;
 	tpAggrAddTsParams pAggrAddTsParam;
 	tpPESession psessionEntry = NULL;
diff --git a/core/mac/src/pe/lim/lim_ft_preauth.c b/core/mac/src/pe/lim/lim_ft_preauth.c
index 920874c..d6b0d29 100644
--- a/core/mac/src/pe/lim/lim_ft_preauth.c
+++ b/core/mac/src/pe/lim/lim_ft_preauth.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2016-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -126,7 +126,7 @@
  *
  * Return: value to indicate if buffer was consumed
  */
-int lim_process_ft_pre_auth_req(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
+int lim_process_ft_pre_auth_req(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
 	int buf_consumed = false;
 	tpPESession session;
@@ -600,7 +600,7 @@
 			      tpPESession session)
 {
 	tpSirFTPreAuthRsp ft_pre_auth_rsp;
-	tSirMsgQ mmh_msg;
+	struct scheduler_msg mmh_msg;
 	uint16_t rsp_len = sizeof(tSirFTPreAuthRsp);
 
 	ft_pre_auth_rsp = (tpSirFTPreAuthRsp) qdf_mem_malloc(rsp_len);
@@ -681,7 +681,7 @@
 {
 	tSirScanOffloadReq *scan_offload_req;
 	tSirRetStatus rc = eSIR_SUCCESS;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	scan_offload_req = qdf_mem_malloc(sizeof(tSirScanOffloadReq));
 	if (NULL == scan_offload_req) {
diff --git a/core/mac/src/pe/lim/lim_link_monitoring_algo.c b/core/mac/src/pe/lim/lim_link_monitoring_algo.c
index 4f678f3..80e308e 100644
--- a/core/mac/src/pe/lim/lim_link_monitoring_algo.c
+++ b/core/mac/src/pe/lim/lim_link_monitoring_algo.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -208,7 +208,7 @@
  *
  * Return: none
  */
-void lim_delete_sta_context(tpAniSirGlobal mac_ctx, tpSirMsgQ lim_msg)
+void lim_delete_sta_context(tpAniSirGlobal mac_ctx, struct scheduler_msg *lim_msg)
 {
 	tpDeleteStaContext msg = (tpDeleteStaContext) lim_msg->bodyptr;
 	tpPESession session_entry;
diff --git a/core/mac/src/pe/lim/lim_p2p.c b/core/mac/src/pe/lim/lim_p2p.c
index 97b462b..da25c06 100644
--- a/core/mac/src/pe/lim/lim_p2p.c
+++ b/core/mac/src/pe/lim/lim_p2p.c
@@ -80,7 +80,7 @@
 							  pRemOnChnReq)
 {
 	tSirScanOffloadReq *pScanOffloadReq;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirRetStatus rc = eSIR_SUCCESS;
 
 	pScanOffloadReq = qdf_mem_malloc(sizeof(tSirScanOffloadReq));
@@ -522,7 +522,7 @@
  * Return: NULL
  */
 void lim_send_p2p_action_frame(tpAniSirGlobal mac_ctx,
-		tpSirMsgQ msg)
+		struct scheduler_msg *msg)
 {
 	tSirMbMsgP2p *mb_msg = (tSirMbMsgP2p *) msg->bodyptr;
 	uint32_t msg_len;
@@ -745,7 +745,7 @@
 {
 	tpP2pPsConfig pNoA;
 	tpP2pPsParams pMsgNoA;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	pNoA = (tpP2pPsConfig) pMsgBuf;
 
diff --git a/core/mac/src/pe/lim/lim_process_action_frame.c b/core/mac/src/pe/lim/lim_process_action_frame.c
index 652d3d9..efe3404 100644
--- a/core/mac/src/pe/lim/lim_process_action_frame.c
+++ b/core/mac/src/pe/lim/lim_process_action_frame.c
@@ -416,7 +416,7 @@
 	if (eLIM_AP_ROLE == session_entry->limSystemRole) {
 
 		struct sir_sme_ext_cng_chan_ind *ext_cng_chan_ind;
-		tSirMsgQ mmh_msg;
+		struct scheduler_msg mmh_msg;
 
 		ext_cng_chan_ind = qdf_mem_malloc(sizeof(*ext_cng_chan_ind));
 		if (NULL == ext_cng_chan_ind) {
diff --git a/core/mac/src/pe/lim/lim_process_cfg_updates.c b/core/mac/src/pe/lim/lim_process_cfg_updates.c
index 7f4c16e..e16cda6 100644
--- a/core/mac/src/pe/lim/lim_process_cfg_updates.c
+++ b/core/mac/src/pe/lim/lim_process_cfg_updates.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -156,7 +156,7 @@
  */
 void lim_handle_param_update(tpAniSirGlobal pMac, eUpdateIEsType cfgId)
 {
-	tSirMsgQ msg = { 0 };
+	struct scheduler_msg msg = { 0 };
 	uint32_t status;
 
 	PELOG3(lim_log
@@ -247,7 +247,7 @@
 		break;
 	case WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG:
 	{
-		tSirMsgQ msg = { 0 };
+		struct scheduler_msg msg = { 0 };
 		uint32_t status;
 
 		msg.type = SIR_LIM_UPDATE_BEACON;
diff --git a/core/mac/src/pe/lim/lim_process_mlm_host_roam.c b/core/mac/src/pe/lim/lim_process_mlm_host_roam.c
index 00e22ec..38b6b1c 100644
--- a/core/mac/src/pe/lim/lim_process_mlm_host_roam.c
+++ b/core/mac/src/pe/lim/lim_process_mlm_host_roam.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2016-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -361,7 +361,7 @@
  *Return: None
  */
 void lim_process_sta_mlm_add_bss_rsp_ft(tpAniSirGlobal pMac,
-		tpSirMsgQ limMsgQ, tpPESession psessionEntry)
+		struct scheduler_msg *limMsgQ, tpPESession psessionEntry)
 {
 	tLimMlmReassocCnf mlmReassocCnf; /* keep sme */
 	tpDphHashNode pStaDs = NULL;
@@ -606,7 +606,7 @@
 	tLimMlmReassocReq *pMlmReassocReq;
 	uint16_t caps;
 	uint32_t val;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode;
 	uint32_t teleBcnEn = 0;
 
diff --git a/core/mac/src/pe/lim/lim_process_mlm_req_messages.c b/core/mac/src/pe/lim/lim_process_mlm_req_messages.c
index 7cf6c5e..5bd3a1b 100644
--- a/core/mac/src/pe/lim/lim_process_mlm_req_messages.c
+++ b/core/mac/src/pe/lim/lim_process_mlm_req_messages.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -82,7 +82,7 @@
  *
  * Return: None
  */
-void lim_process_mlm_req_messages(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
+void lim_process_mlm_req_messages(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
 	switch (msg->type) {
 	case LIM_MLM_START_REQ:
@@ -477,7 +477,7 @@
 lim_mlm_add_bss(tpAniSirGlobal mac_ctx,
 		tLimMlmStartReq *mlm_start_req, tpPESession session)
 {
-	tSirMsgQ msg_buf;
+	struct scheduler_msg msg_buf;
 	tpAddBssParams addbss_param = NULL;
 	uint32_t retcode;
 	bool is_ch_dfs = false;
diff --git a/core/mac/src/pe/lim/lim_process_probe_req_frame.c b/core/mac/src/pe/lim/lim_process_probe_req_frame.c
index 1cea1de..c367d0d 100644
--- a/core/mac/src/pe/lim/lim_process_probe_req_frame.c
+++ b/core/mac/src/pe/lim/lim_process_probe_req_frame.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -657,7 +657,7 @@
 			   uint32_t ProbeReqIELen, tpPESession psessionEntry)
 {
 	tSirSmeProbeReqInd *pSirSmeProbeReqInd;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pSirSmeProbeReqInd = qdf_mem_malloc(sizeof(tSirSmeProbeReqInd));
 	if (NULL == pSirSmeProbeReqInd) {
diff --git a/core/mac/src/pe/lim/lim_process_sme_req_messages.c b/core/mac/src/pe/lim/lim_process_sme_req_messages.c
index a09107b..4179da6 100644
--- a/core/mac/src/pe/lim/lim_process_sme_req_messages.c
+++ b/core/mac/src/pe/lim/lim_process_sme_req_messages.c
@@ -81,7 +81,7 @@
 
 /* SME REQ processing function templates */
 static bool __lim_process_sme_sys_ready_ind(tpAniSirGlobal, uint32_t *);
-static bool __lim_process_sme_start_bss_req(tpAniSirGlobal, tpSirMsgQ pMsg);
+static bool __lim_process_sme_start_bss_req(tpAniSirGlobal, struct scheduler_msg *pMsg);
 static void __lim_process_sme_scan_req(tpAniSirGlobal, uint32_t *);
 static void __lim_process_sme_join_req(tpAniSirGlobal, uint32_t *);
 static void __lim_process_sme_reassoc_req(tpAniSirGlobal, uint32_t *);
@@ -89,7 +89,7 @@
 static void __lim_process_sme_disassoc_cnf(tpAniSirGlobal, uint32_t *);
 static void __lim_process_sme_deauth_req(tpAniSirGlobal, uint32_t *);
 static void __lim_process_sme_set_context_req(tpAniSirGlobal, uint32_t *);
-static bool __lim_process_sme_stop_bss_req(tpAniSirGlobal, tpSirMsgQ pMsg);
+static bool __lim_process_sme_stop_bss_req(tpAniSirGlobal, struct scheduler_msg *pMsg);
 static void __lim_process_send_disassoc_frame(tpAniSirGlobal mac_ctx,
 				uint32_t *msg_buf);
 static void lim_process_sme_channel_change_request(tpAniSirGlobal pMac,
@@ -136,7 +136,7 @@
 	struct sir_hw_mode *req_msg;
 	uint32_t len;
 	struct s_sir_set_hw_mode *buf;
-	tSirMsgQ resp_msg;
+	struct scheduler_msg resp_msg;
 	struct sir_set_hw_mode_resp *param;
 
 	buf = (struct s_sir_set_hw_mode *) msg;
@@ -207,7 +207,7 @@
 	struct sir_dual_mac_config *req_msg;
 	uint32_t len;
 	struct sir_set_dual_mac_cfg *buf;
-	tSirMsgQ resp_msg;
+	struct scheduler_msg resp_msg;
 	struct sir_dual_mac_config_resp *param;
 
 	buf = (struct sir_set_dual_mac_cfg *) msg;
@@ -278,7 +278,7 @@
 	struct scheduler_msg message;
 	struct sir_antenna_mode_param *req_msg;
 	struct sir_set_antenna_mode *buf;
-	tSirMsgQ resp_msg;
+	struct scheduler_msg resp_msg;
 	struct sir_antenna_mode_resp *param;
 
 	buf = (struct sir_set_antenna_mode *) msg;
@@ -478,7 +478,7 @@
  * Return: true - If defered false - Otherwise
  */
 
-static bool __lim_is_defered_msg_for_learn(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+static bool __lim_is_defered_msg_for_learn(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	if (lim_is_system_in_scan_state(pMac)) {
 		if (lim_defer_msg(pMac, pMsg) != TX_SUCCESS) {
@@ -505,7 +505,7 @@
  * Return: true, if defered otherwise return false.
  */
 static bool
-__lim_is_defered_msg_for_radar(tpAniSirGlobal mac_ctx, tpSirMsgQ message)
+__lim_is_defered_msg_for_radar(tpAniSirGlobal mac_ctx, struct scheduler_msg *message)
 {
 	/*
 	 * fRadarDetCurOperChan will be set only if we
@@ -543,7 +543,7 @@
 
 static bool __lim_process_sme_sys_ready_ind(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirSmeReadyReq *ready_req = (tSirSmeReadyReq *) pMsgBuf;
 
 	msg.type = WMA_SYS_READY_IND;
@@ -1171,7 +1171,7 @@
  * return true - If we consumed the buffer
  *        false - If have defered the message.
  */
-static bool __lim_process_sme_start_bss_req(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+static bool __lim_process_sme_start_bss_req(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	if (__lim_is_defered_msg_for_learn(pMac, pMsg) ||
 	    __lim_is_defered_msg_for_radar(pMac, pMsg)) {
@@ -1218,7 +1218,7 @@
 {
 	tSirScanOffloadReq *pScanOffloadReq;
 	uint8_t *p;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	uint16_t i, len;
 	uint16_t addn_ie_len = 0;
 	tSirRetStatus status, rc = eSIR_SUCCESS;
@@ -1468,7 +1468,7 @@
  * @param  *pMsgBuf  A pointer to the SME message buffer
  * @return None
  */
-static void __lim_process_clear_dfs_channel_list(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+static void __lim_process_clear_dfs_channel_list(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	qdf_mem_set(&pMac->lim.dfschannelList, sizeof(tSirDFSChannelList), 0);
 }
@@ -3456,7 +3456,7 @@
  *         false - If have defered the message.
  */
 
-static bool __lim_process_sme_stop_bss_req(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+static bool __lim_process_sme_stop_bss_req(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	if (__lim_is_defered_msg_for_learn(pMac, pMsg)) {
 		/**
@@ -3969,7 +3969,7 @@
 __lim_process_sme_get_statistics_request(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
 {
 	tpAniGetPEStatsReq pPEStatsReq;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pPEStatsReq = (tpAniGetPEStatsReq) pMsgBuf;
 
@@ -4002,7 +4002,7 @@
 static void
 __lim_process_sme_get_tsm_stats_request(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	msgQ.type = WMA_TSM_STATS_REQ;
 	msgQ.reserved = 0;
@@ -4068,7 +4068,7 @@
 		      tpPESession psessionEntry, uint8_t sessionId)
 {
 	tpHalHiddenSsidVdevRestart pHalHiddenSsidVdevRestart = NULL;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode = eSIR_SUCCESS;
 
 	if (psessionEntry == NULL) {
@@ -4117,7 +4117,7 @@
 						uint32_t *msg_buf)
 {
 	tpPESession pe_session;
-	tSirMsgQ wma_msg;
+	struct scheduler_msg wma_msg;
 	tSirRetStatus status;
 	tSirRoamOffloadScanReq *req_buffer;
 	uint16_t local_ie_len;
@@ -4482,7 +4482,7 @@
  * @return None
  */
 
-static void __lim_process_report_message(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+static void __lim_process_report_message(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	switch (pMsg->type) {
 	case eWNI_SME_NEIGHBOR_REPORT_REQ_IND:
@@ -4518,7 +4518,7 @@
 {
 	tpMaxTxPowerParams pMaxTxParams = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	if (pSessionEntry == NULL) {
 		lim_log(pMac, LOGE, FL("Inavalid parameters"));
@@ -4866,7 +4866,7 @@
 		uint8_t nss)
 {
 	struct set_ie_param *ie_params;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirRetStatus rc = eSIR_SUCCESS;
 	uint8_t *p_ie = NULL;
 	tHtCaps *p_ht_cap;
@@ -4940,7 +4940,7 @@
 		uint8_t nss)
 {
 	struct set_ie_param *ie_params;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirRetStatus rc = eSIR_SUCCESS;
 	uint8_t *p_ie = NULL;
 	tSirMacVHTCapabilityInfo *vht_cap;
@@ -5140,7 +5140,7 @@
  *                   false - if pMsgBuf is not to be freed.
  */
 
-bool lim_process_sme_req_messages(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+bool lim_process_sme_req_messages(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	bool bufConsumed = true;        /* Set this flag to false within case block of any following message, that doesnt want pMsgBuf to be freed. */
 	uint32_t *pMsgBuf = pMsg->bodyptr;
diff --git a/core/mac/src/pe/lim/lim_process_tdls.c b/core/mac/src/pe/lim/lim_process_tdls.c
index dd3947d..8add661 100644
--- a/core/mac/src/pe/lim/lim_process_tdls.c
+++ b/core/mac/src/pe/lim/lim_process_tdls.c
@@ -2797,7 +2797,7 @@
 						uint8_t updateSta,
 						tDphHashNode *pStaDs, uint8_t status)
 {
-	tSirMsgQ mmhMsg = { 0 };
+	struct scheduler_msg mmhMsg = { 0 };
 	tSirTdlsAddStaRsp *addStaRsp = NULL;
 	mmhMsg.type = eWNI_SME_TDLS_ADD_STA_RSP;
 
@@ -3010,7 +3010,7 @@
 					      struct qdf_mac_addr *peermac,
 					      tDphHashNode *pStaDs, uint8_t status)
 {
-	tSirMsgQ mmhMsg = { 0 };
+	struct scheduler_msg mmhMsg = { 0 };
 
 	tSirTdlsLinkEstablishReqRsp *pTdlsLinkEstablishReqRsp = NULL;
 
@@ -3042,7 +3042,7 @@
 						struct qdf_mac_addr peerMac,
 						tDphHashNode *pStaDs, uint8_t status)
 {
-	tSirMsgQ mmhMsg = { 0 };
+	struct scheduler_msg mmhMsg = { 0 };
 	tSirTdlsDelStaRsp *pDelSta = NULL;
 	mmhMsg.type = eWNI_SME_TDLS_DEL_STA_RSP;
 
@@ -3258,7 +3258,7 @@
 	tpPESession session_entry;
 	uint8_t session_id;
 	tpTdlsLinkEstablishParams tdls_req_params;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	uint16_t peer_idx = 0;
 	tpDphHashNode stads = NULL;
 	uint32_t self_num_chan = WNI_CFG_VALID_CHANNEL_LIST_LEN;
diff --git a/core/mac/src/pe/lim/lim_reassoc_utils.c b/core/mac/src/pe/lim/lim_reassoc_utils.c
index d9d4024..65bc733 100644
--- a/core/mac/src/pe/lim/lim_reassoc_utils.c
+++ b/core/mac/src/pe/lim/lim_reassoc_utils.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2016-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -445,7 +445,7 @@
 {
 	tpAddStaParams add_sta_params = NULL;
 	tSirRetStatus ret_code = eSIR_SUCCESS;
-	tSirMsgQ msg_q;
+	struct scheduler_msg msg_q;
 
 	add_sta_params = session_entry->ftPEContext.pAddStaReq;
 	add_sta_params->assocId = assoc_id;
diff --git a/core/mac/src/pe/lim/lim_security_utils.c b/core/mac/src/pe/lim/lim_security_utils.c
index c5938c2..1d98c7e 100644
--- a/core/mac/src/pe/lim/lim_security_utils.c
+++ b/core/mac/src/pe/lim/lim_security_utils.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2013-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -816,7 +816,7 @@
 			      tLimMlmSetKeysReq *pMlmSetKeysReq,
 			      tpPESession psessionEntry)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpSetBssKeyParams pSetBssKeyParams = NULL;
 	tLimMlmSetKeysCnf mlmSetKeysCnf;
 	tSirRetStatus retCode;
@@ -929,7 +929,7 @@
 			      uint8_t defWEPIdx,
 			      tpPESession sessionEntry, bool sendRsp)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpSetStaKeyParams pSetStaKeyParams = NULL;
 	tLimMlmSetKeysCnf mlmSetKeysCnf;
 	tSirRetStatus retCode;
diff --git a/core/mac/src/pe/lim/lim_send_messages.c b/core/mac/src/pe/lim/lim_send_messages.c
index 3222cf0..97eeacf 100644
--- a/core/mac/src/pe/lim/lim_send_messages.c
+++ b/core/mac/src/pe/lim/lim_send_messages.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -94,7 +94,7 @@
 {
 	tpUpdateCFParams pCFParams = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pCFParams = qdf_mem_malloc(sizeof(tUpdateCFParams));
 	if (NULL == pCFParams) {
@@ -142,7 +142,7 @@
 {
 	tpUpdateBeaconParams pBcnParams = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pBcnParams = qdf_mem_malloc(sizeof(*pBcnParams));
 	if (NULL == pBcnParams) {
@@ -211,7 +211,7 @@
 					  uint8_t is_restart)
 {
 	tpSwitchChannelParams pChnlParams = NULL;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpPESession pSessionEntry;
 	pSessionEntry = pe_find_session_by_session_id(pMac, peSessionId);
 	if (pSessionEntry == NULL) {
@@ -314,7 +314,7 @@
 {
 	tEdcaParams *pEdcaParams = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	uint8_t i;
 
 	pEdcaParams = qdf_mem_malloc(sizeof(tEdcaParams));
@@ -477,7 +477,7 @@
 				 tpSetLinkStateCallback callback,
 				 void *callbackArg)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode;
 	tpLinkStateParams pLinkStateParams = NULL;
 	/* Allocate memory. */
@@ -519,7 +519,7 @@
 					   tSirMacAddr selfMacAddr, int ft,
 					   tpPESession psessionEntry)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirRetStatus retCode;
 	tpLinkStateParams pLinkStateParams = NULL;
 	/* Allocate memory. */
@@ -570,7 +570,7 @@
 {
 	tpBeaconFilterMsg pBeaconFilterMsg = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	uint8_t *ptr;
 	uint32_t i;
 	uint32_t msgSize;
@@ -636,7 +636,7 @@
 {
 	tUpdateVHTOpMode *pVhtOpMode = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pVhtOpMode = qdf_mem_malloc(sizeof(tUpdateVHTOpMode));
 	if (NULL == pVhtOpMode) {
@@ -676,7 +676,7 @@
 {
 	tUpdateRxNss *pRxNss = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pRxNss = qdf_mem_malloc(sizeof(tUpdateRxNss));
 	if (NULL == pRxNss) {
@@ -713,7 +713,7 @@
 {
 	tUpdateMembership *pMembership = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pMembership = qdf_mem_malloc(sizeof(tUpdateMembership));
 	if (NULL == pMembership) {
@@ -752,7 +752,7 @@
 {
 	tUpdateUserPos *pUserPos = NULL;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	pUserPos = qdf_mem_malloc(sizeof(tUpdateUserPos));
 	if (NULL == pUserPos) {
@@ -801,7 +801,7 @@
 					     tpPESession psessionEntry)
 {
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirWlanExcludeUnencryptParam *pExcludeUnencryptParam;
 
 	pExcludeUnencryptParam =
@@ -849,7 +849,7 @@
 	enum eSirRetStatus ret = eSIR_SUCCESS;
 	struct obss_ht40_scanind *ht40_obss_scanind;
 	uint32_t channelnum;
-	struct sSirMsgQ msg;
+	struct scheduler_msg msg;
 	uint8_t chan_list[WNI_CFG_VALID_CHANNEL_LIST_LEN];
 	uint8_t channel24gnum, count;
 
diff --git a/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c b/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c
index 1e0f955..f52177a 100644
--- a/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c
+++ b/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c
@@ -84,7 +84,7 @@
 	 tSirResultCodes result_code, uint8_t sme_session_id,
 	 uint16_t sme_transaction_id)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirSmeRsp *sme_rsp;
 
 	lim_log(mac_ctx, LOG1, FL("Sending message %s with reasonCode %s"),
@@ -142,7 +142,7 @@
 	 tSirResultCodes result_code, uint8_t sme_session_id,
 	 uint32_t scan_id)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	struct sir_roc_rsp *sme_rsp;
 
 	lim_log(mac_ctx, LOG1,
@@ -236,7 +236,7 @@
 static void lim_send_sme_join_reassoc_rsp_after_resume(tpAniSirGlobal mac_ctx,
 	QDF_STATUS status, uint32_t *ctx)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpSirSmeJoinRsp sme_join_rsp = (tpSirSmeJoinRsp) ctx;
 
 	msg.type = sme_join_rsp->messageType;
@@ -570,7 +570,7 @@
 {
 
 	uint16_t size = 0;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirSmeStartBssRsp *pSirSmeRsp;
 	uint16_t ieLen;
 	uint16_t ieOffset, curLen;
@@ -753,7 +753,7 @@
 			uint32_t scan_id)
 {
 	tpSirSmeScanRsp pSirSmeScanRsp;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	lim_log(pMac, LOG1, FL("send SME_SCAN_RSP (reasonCode %s)."),
 		lim_result_code_str(resultCode));
@@ -791,8 +791,8 @@
 void lim_send_sme_disassoc_deauth_ntf(tpAniSirGlobal pMac,
 				      QDF_STATUS status, uint32_t *pCtx)
 {
-	tSirMsgQ mmhMsg;
-	tSirMsgQ *pMsg = (tSirMsgQ *) pCtx;
+	struct scheduler_msg mmhMsg;
+	struct scheduler_msg *pMsg = (struct scheduler_msg *) pCtx;
 
 	mmhMsg.type = pMsg->type;
 	mmhMsg.bodyptr = pMsg;
@@ -1030,7 +1030,7 @@
 lim_send_sme_disassoc_ind(tpAniSirGlobal pMac, tpDphHashNode pStaDs,
 			  tpPESession psessionEntry)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirSmeDisassocInd *pSirSmeDisassocInd;
 
 	pSirSmeDisassocInd = qdf_mem_malloc(sizeof(tSirSmeDisassocInd));
@@ -1087,7 +1087,7 @@
 lim_send_sme_deauth_ind(tpAniSirGlobal pMac, tpDphHashNode pStaDs,
 			tpPESession psessionEntry)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirSmeDeauthInd *pSirSmeDeauthInd;
 
 	pSirSmeDeauthInd = qdf_mem_malloc(sizeof(tSirSmeDeauthInd));
@@ -1161,7 +1161,7 @@
 lim_send_sme_tdls_del_sta_ind(tpAniSirGlobal pMac, tpDphHashNode pStaDs,
 			      tpPESession psessionEntry, uint16_t reasonCode)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirTdlsDelStaInd *pSirTdlsDelStaInd;
 
 	pSirTdlsDelStaInd = qdf_mem_malloc(sizeof(tSirTdlsDelStaInd));
@@ -1221,7 +1221,7 @@
 void
 lim_send_sme_tdls_delete_all_peer_ind(tpAniSirGlobal pMac, tpPESession psessionEntry)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirTdlsDelAllPeerInd *pSirTdlsDelAllPeerInd;
 
 	pSirTdlsDelAllPeerInd = qdf_mem_malloc(sizeof(tSirTdlsDelAllPeerInd));
@@ -1269,7 +1269,7 @@
 lim_send_sme_mgmt_tx_completion(tpAniSirGlobal pMac,
 				tpPESession psessionEntry, uint32_t txCompleteStatus)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirMgmtTxCompletionInd *pSirMgmtTxCompletionInd;
 
 	pSirMgmtTxCompletionInd =
@@ -1301,7 +1301,7 @@
 void lim_send_sme_tdls_event_notify(tpAniSirGlobal pMac, uint16_t msgType,
 				    void *events)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	switch (msgType) {
 	case SIR_HAL_TDLS_SHOULD_DISCOVER:
@@ -1509,7 +1509,7 @@
 	tSirSmeStatusChangeCode status_change_code,
 	uint32_t *status_change_info, uint16_t info_len, uint8_t session_id)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirSmeWmStatusChangeNtf *wm_status_change_ntf;
 	uint32_t max_info_len;
 
@@ -1598,7 +1598,7 @@
 			     tpPESession psessionEntry, uint8_t smesessionId,
 			     uint16_t smetransactionId)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirSmeSetContextRsp *pSirSmeSetContextRsp;
 
 	pSirSmeSetContextRsp = qdf_mem_malloc(sizeof(tSirSmeSetContextRsp));
@@ -1666,7 +1666,7 @@
 void
 lim_send_sme_neighbor_bss_ind(tpAniSirGlobal pMac, tLimScanResultNode *pBssDescr)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	uint32_t val;
 	tSirSmeNeighborBssInd *pNewBssInd;
 
@@ -1740,7 +1740,7 @@
 		       uint8_t smesessionId, uint16_t smetransactionId)
 {
 	tpSirAddtsRsp rsp;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	if (!rspReqd)
 		return;
@@ -1784,7 +1784,7 @@
 		       uint16_t smetransactionId)
 {
 	tpSirDeltsRsp rsp;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	lim_log(pMac, LOGW, "SendSmeDeltsRsp (aid %d, tsid %d, up %d) status %d",
 		delts->aid,
@@ -1838,7 +1838,7 @@
 		       tpPESession psessionEntry)
 {
 	tpSirDeltsRsp rsp;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	lim_log(pMac, LOGW, "SendSmeDeltsInd (aid %d, tsid %d, up %d)",
 		aid, delts->tsinfo.traffic.tsid, delts->tsinfo.traffic.userPrio);
@@ -1901,7 +1901,7 @@
 void
 lim_send_sme_pe_statistics_rsp(tpAniSirGlobal pMac, uint16_t msgType, void *stats)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	uint8_t sessionId;
 	tAniGetPEStatsRsp *pPeStats = (tAniGetPEStatsRsp *) stats;
 	tpPESession pPeSessionEntry;
@@ -1945,7 +1945,7 @@
 void lim_send_sme_pe_ese_tsm_rsp(tpAniSirGlobal pMac,
 				 tAniGetTsmStatsRsp *pStats)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	uint8_t sessionId;
 	tAniGetTsmStatsRsp *pPeStats = (tAniGetTsmStatsRsp *) pStats;
 	tpPESession pPeSessionEntry = NULL;
@@ -1991,7 +1991,7 @@
 			   uint8_t *beacon,
 			   uint16_t beaconLen, uint16_t msgType, uint8_t sessionId)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSmeIbssPeerInd *pNewPeerInd;
 
 	pNewPeerInd = qdf_mem_malloc(sizeof(tSmeIbssPeerInd) + beaconLen);
@@ -2099,10 +2099,10 @@
  *
  * Return: None
  */
-void lim_handle_csa_offload_msg(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
+void lim_handle_csa_offload_msg(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
 	tpPESession session_entry;
-	tSirMsgQ mmh_msg;
+	struct scheduler_msg mmh_msg;
 	struct csa_offload_params *csa_params =
 				(struct csa_offload_params *) (msg->bodyptr);
 	tpSmeCsaOffloadInd csa_offload_ind;
@@ -2330,7 +2330,7 @@
    \sa
    --------------------------------------------------------------------------*/
 
-void lim_handle_delete_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ MsgQ)
+void lim_handle_delete_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *MsgQ)
 {
 	tpPESession psessionEntry;
 	tpDeleteBssParams pDelBss = (tpDeleteBssParams) (MsgQ->bodyptr);
@@ -2376,7 +2376,7 @@
 lim_send_sme_aggr_qos_rsp(tpAniSirGlobal pMac, tpSirAggrQosRsp aggrQosRsp,
 			  uint8_t smesessionId)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	mmhMsg.type = eWNI_SME_FT_AGGR_QOS_RSP;
 	mmhMsg.bodyptr = aggrQosRsp;
@@ -2391,7 +2391,7 @@
 void lim_send_sme_max_assoc_exceeded_ntf(tpAniSirGlobal pMac, tSirMacAddr peerMacAddr,
 					 uint8_t smesessionId)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSmeMaxAssocInd *pSmeMaxAssocInd;
 
 	pSmeMaxAssocInd = qdf_mem_malloc(sizeof(tSmeMaxAssocInd));
@@ -2434,7 +2434,7 @@
 void
 lim_send_sme_dfs_event_notify(tpAniSirGlobal pMac, uint16_t msgType, void *event)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	mmhMsg.type = eWNI_SME_DFS_RADAR_FOUND;
 	mmhMsg.bodyptr = event;
 	mmhMsg.bodyval = 0;
@@ -2486,7 +2486,7 @@
 				    tpPESession psessionEntry,
 				    tpSwitchChannelParams pChnlParams)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tpSwitchChannelParams pSmeSwithChnlParams;
 	uint8_t channelId;
 	bool is_ch_dfs = false;
@@ -2574,7 +2574,7 @@
 	 * add appropriate code by introducing a state variable
 	 */
 	tpPESession psessionEntry;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tSirSmeCSAIeTxCompleteRsp *pChanSwTxResponse;
 	struct sir_beacon_tx_complete_rsp *beacon_tx_comp_rsp_ptr;
 	uint8_t length = sizeof(tSirSmeCSAIeTxCompleteRsp);
diff --git a/core/mac/src/pe/lim/lim_send_sme_rsp_messages.h b/core/mac/src/pe/lim/lim_send_sme_rsp_messages.h
index 55a58ff..203dca7 100644
--- a/core/mac/src/pe/lim/lim_send_sme_rsp_messages.h
+++ b/core/mac/src/pe/lim/lim_send_sme_rsp_messages.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -70,8 +70,8 @@
 void lim_send_sme_set_context_rsp(tpAniSirGlobal, struct qdf_mac_addr, uint16_t,
 				  tSirResultCodes, tpPESession, uint8_t, uint16_t);
 void lim_send_sme_neighbor_bss_ind(tpAniSirGlobal, tLimScanResultNode *);
-void lim_handle_delete_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ MsgQ);
-void lim_handle_csa_offload_msg(tpAniSirGlobal mac_ctx, tpSirMsgQ msg);
+void lim_handle_delete_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *MsgQ);
+void lim_handle_csa_offload_msg(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg);
 
 void
 lim_send_sme_aggr_qos_rsp(tpAniSirGlobal pMac, tpSirAggrQosRsp aggrQosRsp,
diff --git a/core/mac/src/pe/lim/lim_timer_utils.c b/core/mac/src/pe/lim/lim_timer_utils.c
index 2111ac5..48f510d 100644
--- a/core/mac/src/pe/lim/lim_timer_utils.c
+++ b/core/mac/src/pe/lim/lim_timer_utils.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -448,7 +448,7 @@
 void lim_timer_handler(void *pMacGlobal, uint32_t param)
 {
 	uint32_t statusCode;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	/* Prepare and post message to LIM Message Queue */
@@ -487,7 +487,7 @@
 
 void lim_addts_response_timer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	/* Prepare and post message to LIM Message Queue */
@@ -522,7 +522,7 @@
 
 void lim_auth_response_timer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	/* Prepare and post message to LIM Message Queue */
@@ -548,7 +548,7 @@
  */
 void lim_assoc_failure_timer_handler(void *mac_global, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal mac_ctx = (tpAniSirGlobal) mac_global;
 	tpPESession session = NULL;
 
@@ -605,7 +605,7 @@
  */
 void lim_update_olbc_cache_timer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	/* Prepare and post message to LIM Message Queue */
@@ -1224,7 +1224,7 @@
 
 void lim_cnf_wait_tmer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	uint32_t statusCode;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
@@ -1241,7 +1241,7 @@
 
 void lim_channel_switch_timer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	PELOG1(lim_log(pMac, LOG1,
@@ -1257,7 +1257,7 @@
 
 void lim_quiet_timer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	msg.type = SIR_LIM_QUIET_TIMEOUT;
@@ -1270,7 +1270,7 @@
 
 void lim_quiet_bss_timer_handler(void *pMacGlobal, uint32_t param)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpAniSirGlobal pMac = (tpAniSirGlobal) pMacGlobal;
 
 	msg.type = SIR_LIM_QUIET_BSS_TIMEOUT;
diff --git a/core/mac/src/pe/lim/lim_types.h b/core/mac/src/pe/lim/lim_types.h
index 9e77804..91abe42 100644
--- a/core/mac/src/pe/lim/lim_types.h
+++ b/core/mac/src/pe/lim/lim_types.h
@@ -404,8 +404,8 @@
 
 /* Function templates */
 
-bool lim_process_sme_req_messages(tpAniSirGlobal, tpSirMsgQ);
-void lim_process_mlm_req_messages(tpAniSirGlobal, tpSirMsgQ);
+bool lim_process_sme_req_messages(tpAniSirGlobal, struct scheduler_msg *);
+void lim_process_mlm_req_messages(tpAniSirGlobal, struct scheduler_msg *);
 void lim_process_mlm_rsp_messages(tpAniSirGlobal, uint32_t, uint32_t *);
 void lim_process_sme_del_bss_rsp(tpAniSirGlobal, uint32_t, tpPESession);
 
@@ -569,7 +569,7 @@
 void limHandleMaxRetriesInterrupt(uint32_t);
 
 /* / Function that defers the messages received */
-uint32_t lim_defer_msg(tpAniSirGlobal, tSirMsgQ *);
+uint32_t lim_defer_msg(tpAniSirGlobal, struct scheduler_msg *);
 
 /* / Function that Switches the Channel and sets the CB Mode */
 void lim_set_channel(tpAniSirGlobal pMac, uint8_t channel,
@@ -596,20 +596,20 @@
 				tpPESession psessionEntry);
 
 /* Function(s) to handle responses received from HAL */
-void lim_process_mlm_add_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ);
-void lim_process_mlm_add_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQt,
+void lim_process_mlm_add_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ);
+void lim_process_mlm_add_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQt,
 				 tpPESession psessionEntry);
-void lim_process_mlm_del_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ);
-void lim_process_mlm_del_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_mlm_del_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ);
+void lim_process_mlm_del_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				 tpPESession);
-void lim_process_sta_mlm_add_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_sta_mlm_add_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				     tpPESession psessionEntry);
-void lim_process_sta_mlm_del_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_sta_mlm_del_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				     tpPESession psessionEntry);
-void lim_process_sta_mlm_del_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_sta_mlm_del_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				     tpPESession psessionEntry);
-void lim_process_mlm_set_sta_key_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ);
-void lim_process_mlm_set_bss_key_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ);
+void lim_process_mlm_set_sta_key_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ);
+void lim_process_mlm_set_bss_key_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ);
 
 /* Function to process WMA_SWITCH_CHANNEL_RSP message */
 void lim_process_switch_channel_rsp(tpAniSirGlobal pMac, void *);
@@ -662,7 +662,7 @@
 static inline void
 lim_post_sme_message(tpAniSirGlobal pMac, uint32_t msgType, uint32_t *pMsgBuf)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	if (pMsgBuf == NULL) {
 		lim_log(pMac, LOGE, FL("Buffer is Pointing to NULL"));
@@ -710,7 +710,7 @@
 lim_post_mlm_message(tpAniSirGlobal pMac, uint32_t msgType, uint32_t *pMsgBuf)
 {
 
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	if (pMsgBuf == NULL) {
 		lim_log(pMac, LOGE, FL("Buffer is Pointing to NULL"));
 		return;
@@ -841,7 +841,7 @@
 void lim_process_remain_on_chn_timeout(tpAniSirGlobal pMac);
 void lim_process_insert_single_shot_noa_timeout(tpAniSirGlobal pMac);
 void lim_convert_active_channel_to_passive_channel(tpAniSirGlobal pMac);
-void lim_send_p2p_action_frame(tpAniSirGlobal pMac, tpSirMsgQ pMsg);
+void lim_send_p2p_action_frame(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 void lim_abort_remain_on_chan(tpAniSirGlobal pMac, uint8_t sessionId,
 	uint32_t scan_id);
 tSirRetStatus __lim_process_sme_no_a_update(tpAniSirGlobal pMac, uint32_t *pMsgBuf);
diff --git a/core/mac/src/pe/lim/lim_utils.c b/core/mac/src/pe/lim/lim_utils.c
index 8a34e85..e6cbdf5 100644
--- a/core/mac/src/pe/lim/lim_utils.c
+++ b/core/mac/src/pe/lim/lim_utils.c
@@ -818,7 +818,7 @@
 
 void lim_reset_deferred_msg_q(tpAniSirGlobal pMac)
 {
-	tSirMsgQ *read_msg;
+	struct scheduler_msg *read_msg;
 
 	if (pMac->lim.gLimDeferredMsgQ.size > 0) {
 		while ((read_msg = lim_read_deferred_msg_q(pMac)) != NULL) {
@@ -847,7 +847,7 @@
  * Return: none
  */
 
-uint8_t lim_write_deferred_msg_q(tpAniSirGlobal mac_ctx, tpSirMsgQ lim_msg)
+uint8_t lim_write_deferred_msg_q(tpAniSirGlobal mac_ctx, struct scheduler_msg *lim_msg)
 {
 	lim_log(mac_ctx, LOG1,
 		FL("Queue a deferred message (size %d, write %d) - type 0x%x "),
@@ -929,7 +929,7 @@
 	/* save the message to the queue and advanced the write pointer */
 	qdf_mem_copy((uint8_t *) &mac_ctx->lim.gLimDeferredMsgQ.
 			deferredQueue[mac_ctx->lim.gLimDeferredMsgQ.write++],
-				(uint8_t *) lim_msg, sizeof(tSirMsgQ));
+				(uint8_t *) lim_msg, sizeof(struct scheduler_msg));
 	return TX_SUCCESS;
 
 }
@@ -956,9 +956,9 @@
  * Returns the message at the head of the deferred message queue
  */
 
-tSirMsgQ *lim_read_deferred_msg_q(tpAniSirGlobal pMac)
+struct scheduler_msg *lim_read_deferred_msg_q(tpAniSirGlobal pMac)
 {
-	tSirMsgQ *msg;
+	struct scheduler_msg *msg;
 
 	/*
 	** check any messages left. If no, return
@@ -1008,7 +1008,7 @@
 }
 
 tSirRetStatus
-lim_sys_process_mmh_msg_api(tpAniSirGlobal pMac, tSirMsgQ *pMsg, uint8_t qType)
+lim_sys_process_mmh_msg_api(tpAniSirGlobal pMac, struct scheduler_msg *pMsg, uint8_t qType)
 {
 	/* FIXME */
 	sys_process_mmh_msg(pMac, pMsg);
@@ -2622,7 +2622,7 @@
 void lim_switch_channel_cback(tpAniSirGlobal pMac, QDF_STATUS status,
 			      uint32_t *data, tpPESession psessionEntry)
 {
-	tSirMsgQ mmhMsg = { 0 };
+	struct scheduler_msg mmhMsg = { 0 };
 	tSirSmeSwitchChannelInd *pSirSmeSwitchChInd;
 
 	psessionEntry->currentOperChannel = psessionEntry->currentReqChannel;
@@ -4703,7 +4703,7 @@
 					   void *msgParam)
 {
 	/* its PE's responsibility to free msgparam when its done extracting the message parameters. */
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	switch (msgId) {
 	case SIR_LIM_DEL_TS_IND:
@@ -4874,7 +4874,7 @@
    -------------------------------------------------------------*/
 void lim_register_hal_ind_call_back(tpAniSirGlobal pMac)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tpHalIndCB pHalCB;
 
 	pHalCB = qdf_mem_malloc(sizeof(tHalIndCB));
@@ -4910,7 +4910,7 @@
  *
  * Return: none
  */
-void lim_process_del_ts_ind(tpAniSirGlobal pMac, tpSirMsgQ limMsg)
+void lim_process_del_ts_ind(tpAniSirGlobal pMac, struct scheduler_msg *limMsg)
 {
 	tpDphHashNode pSta;
 	tpDelTsParams pDelTsParam = (tpDelTsParams) (limMsg->bodyptr);
@@ -5031,7 +5031,7 @@
 			 uint8_t *pPeerStaMac, uint8_t sessionId)
 {
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpSetMIMOPS pMIMO_PSParams;
 
 	msgQ.reserved = 0;
@@ -5228,7 +5228,7 @@
 
 	QDF_STATUS status = QDF_STATUS_E_FAILURE;
 	tpTxControlParams pTxCtrlMsg;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	uint8_t nBytes = 0; /* No of bytes required for station bitmap. */
 
 	/** Allocate only required number of bytes for station bitmap
@@ -5596,7 +5596,7 @@
  *
  * @Return: void
  */
-void lim_process_add_sta_rsp(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
+void lim_process_add_sta_rsp(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
 	tpPESession session;
 	tpAddStaParams add_sta_params;
@@ -5764,7 +5764,7 @@
    \return void
    -----------------------------------------------------------*/
 
-void lim_handle_defer_msg_error(tpAniSirGlobal pMac, tpSirMsgQ pLimMsg)
+void lim_handle_defer_msg_error(tpAniSirGlobal pMac, struct scheduler_msg *pLimMsg)
 {
 	if (SIR_BB_XPORT_MGMT_MSG == pLimMsg->type) {
 		cds_pkt_return_packet((cds_pkt_t *) pLimMsg->bodyptr);
@@ -7190,7 +7190,7 @@
 {
 	struct set_dtim_params *dtim_params = NULL;
 	tSirRetStatus ret = eSIR_SUCCESS;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	if (session == NULL) {
 		lim_log(mac_ctx, LOGE, FL("Inavalid parameters"));
diff --git a/core/mac/src/pe/lim/lim_utils.h b/core/mac/src/pe/lim/lim_utils.h
index 0ad24b0..3385903 100644
--- a/core/mac/src/pe/lim/lim_utils.h
+++ b/core/mac/src/pe/lim/lim_utils.h
@@ -200,14 +200,14 @@
 void lim_print_mac_addr(tpAniSirGlobal, tSirMacAddr, uint8_t);
 
 /* Deferred Message Queue read/write */
-uint8_t lim_write_deferred_msg_q(tpAniSirGlobal pMac, tpSirMsgQ limMsg);
-tSirMsgQ *lim_read_deferred_msg_q(tpAniSirGlobal pMac);
-void lim_handle_defer_msg_error(tpAniSirGlobal pMac, tpSirMsgQ pLimMsg);
+uint8_t lim_write_deferred_msg_q(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
+struct scheduler_msg *lim_read_deferred_msg_q(tpAniSirGlobal pMac);
+void lim_handle_defer_msg_error(tpAniSirGlobal pMac, struct scheduler_msg *pLimMsg);
 
 /* Deferred Message Queue Reset */
 void lim_reset_deferred_msg_q(tpAniSirGlobal pMac);
 
-tSirRetStatus lim_sys_process_mmh_msg_api(tpAniSirGlobal, tSirMsgQ *, uint8_t);
+tSirRetStatus lim_sys_process_mmh_msg_api(tpAniSirGlobal, struct scheduler_msg *, uint8_t);
 
 void lim_handle_update_olbc_cache(tpAniSirGlobal pMac);
 
@@ -355,7 +355,7 @@
  * timer fires.
  */
 
-void lim_process_del_ts_ind(tpAniSirGlobal pMac, tpSirMsgQ limMsg);
+void lim_process_del_ts_ind(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
 tSirRetStatus lim_process_hal_ind_messages(tpAniSirGlobal pMac, uint32_t mesgId,
 		void *mesgParam);
 tSirRetStatus lim_validate_delts_req(tpAniSirGlobal pMac,
@@ -396,7 +396,7 @@
 		tSirMacHTMIMOPowerSaveState MIMOPSState,
 		uint8_t *pPeerStaMac, uint8_t sessionId);
 
-void lim_delete_sta_context(tpAniSirGlobal pMac, tpSirMsgQ limMsg);
+void lim_delete_sta_context(tpAniSirGlobal pMac, struct scheduler_msg *limMsg);
 void lim_delete_dialogue_token_list(tpAniSirGlobal pMac);
 void lim_resset_scan_channel_info(tpAniSirGlobal pMac);
 uint8_t lim_get_channel_from_beacon(tpAniSirGlobal pMac,
@@ -411,18 +411,18 @@
 void lim_handle_heart_beat_timeout_for_session(tpAniSirGlobal pMac,
 		tpPESession psessionEntry);
 
-void lim_process_add_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ pMsgQ);
+void lim_process_add_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *pMsgQ);
 
 void lim_update_beacon(tpAniSirGlobal pMac);
 
-void lim_process_ap_mlm_add_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_ap_mlm_add_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 		tpPESession psessionEntry);
 void lim_process_ap_mlm_del_bss_rsp(tpAniSirGlobal pMac,
-		tpSirMsgQ limMsgQ,
+		struct scheduler_msg *limMsgQ,
 		tpPESession psessionEntry);
 
 void lim_process_ap_mlm_del_sta_rsp(tpAniSirGlobal pMac,
-		tpSirMsgQ limMsgQ,
+		struct scheduler_msg *limMsgQ,
 		tpPESession psessionEntry);
 
 tpPESession lim_is_ibss_session_active(tpAniSirGlobal pMac);
diff --git a/core/mac/src/pe/nan/nan_datapath.c b/core/mac/src/pe/nan/nan_datapath.c
index 525d688..1ce321c 100644
--- a/core/mac/src/pe/nan/nan_datapath.c
+++ b/core/mac/src/pe/nan/nan_datapath.c
@@ -46,7 +46,7 @@
 static void lim_send_ndp_event_to_sme(tpAniSirGlobal mac_ctx, uint32_t msg_type,
 				void *body_ptr, uint32_t len, uint32_t body_val)
 {
-	tSirMsgQ mmh_msg = {0};
+	struct scheduler_msg mmh_msg = {0};
 
 	mmh_msg.type = msg_type;
 	if (len && body_ptr) {
@@ -389,7 +389,7 @@
  *
  * Return: None
  */
-void lim_process_ndi_del_sta_rsp(tpAniSirGlobal mac_ctx, tpSirMsgQ lim_msg,
+void lim_process_ndi_del_sta_rsp(tpAniSirGlobal mac_ctx, struct scheduler_msg *lim_msg,
 						tpPESession pe_session)
 {
 	tpDeleteStaParams del_sta_params = (tpDeleteStaParams) lim_msg->bodyptr;
@@ -536,7 +536,7 @@
 static QDF_STATUS lim_process_sme_ndp_initiator_req(tpAniSirGlobal mac_ctx,
 						    void *ndp_msg)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	QDF_STATUS status;
 
 	struct sir_sme_ndp_initiator_req *sme_req =
@@ -585,7 +585,7 @@
 static QDF_STATUS lim_process_sme_ndp_responder_req(tpAniSirGlobal mac_ctx,
 	struct sir_sme_ndp_responder_req *lim_msg)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
 	struct ndp_responder_req *responder_req;
 
@@ -635,7 +635,7 @@
 static QDF_STATUS lim_process_sme_ndp_data_end_req(tpAniSirGlobal mac_ctx,
 					struct sir_sme_ndp_end_req *sme_msg)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	uint32_t len;
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
 
@@ -680,7 +680,7 @@
  * Return: QDF_STATUS_SUCCESS on success; error number otherwise
  */
 QDF_STATUS lim_handle_ndp_request_message(tpAniSirGlobal mac_ctx,
-					  tpSirMsgQ msg)
+					  struct scheduler_msg *msg)
 {
 	QDF_STATUS status;
 
@@ -714,7 +714,7 @@
  *
  * Return: None
  */
-void lim_process_ndi_mlm_add_bss_rsp(tpAniSirGlobal mac_ctx, tpSirMsgQ lim_msgq,
+void lim_process_ndi_mlm_add_bss_rsp(tpAniSirGlobal mac_ctx, struct scheduler_msg *lim_msgq,
 		tpPESession session_entry)
 {
 	tLimMlmStartCnf mlm_start_cnf;
@@ -826,7 +826,7 @@
 					       tpPESession session,
 					       tAddStaParams *add_sta_rsp)
 {
-	tSirMsgQ  mmh_msg = {0};
+	struct scheduler_msg  mmh_msg = {0};
 	struct sme_ndp_peer_ind *new_peer_ind;
 
 	mmh_msg.type = eWNI_SME_NDP_NEW_PEER_IND;
diff --git a/core/mac/src/pe/nan/nan_datapath.h b/core/mac/src/pe/nan/nan_datapath.h
index f895f13..e11cf31 100644
--- a/core/mac/src/pe/nan/nan_datapath.h
+++ b/core/mac/src/pe/nan/nan_datapath.h
@@ -102,12 +102,12 @@
 
 /* Function to process NDP requests */
 QDF_STATUS lim_handle_ndp_request_message(tpAniSirGlobal mac_ctx,
-					tpSirMsgQ msg);
+					struct scheduler_msg *msg);
 /* Function to process NDP events */
 QDF_STATUS lim_handle_ndp_event_message(tpAniSirGlobal mac_ctx,
 					struct scheduler_msg *msg);
 void lim_process_ndi_mlm_add_bss_rsp(tpAniSirGlobal mac_ctx,
-				     tpSirMsgQ lim_msg_q,
+				     struct scheduler_msg *lim_msg_q,
 				     tpPESession session_entry);
 /* Handler for DEL BSS resp for NDI interface */
 void lim_ndi_del_bss_rsp(tpAniSirGlobal  mac_ctx,
@@ -116,14 +116,14 @@
 void lim_ndp_add_sta_rsp(tpAniSirGlobal mac_ctx, tpPESession session_entry,
 			 tAddStaParams *add_sta_rsp);
 
-void lim_process_ndi_del_sta_rsp(tpAniSirGlobal mac_ctx, tpSirMsgQ lim_msg,
+void lim_process_ndi_del_sta_rsp(tpAniSirGlobal mac_ctx, struct scheduler_msg *lim_msg,
 						tpPESession pe_session);
 
 #else
 
 /* Function to process NDP requests */
 static inline QDF_STATUS lim_handle_ndp_request_message(tpAniSirGlobal mac_ctx,
-					tpSirMsgQ msg)
+					struct scheduler_msg *msg)
 {
 	return QDF_STATUS_SUCCESS;
 }
@@ -137,7 +137,7 @@
 
 /* Function to process NDP events */
 static inline void lim_process_ndi_mlm_add_bss_rsp(tpAniSirGlobal mac_ctx,
-						   tpSirMsgQ lim_msg_q,
+						   struct scheduler_msg *lim_msg_q,
 						   tpPESession session_entry)
 {
 }
@@ -146,7 +146,7 @@
 {
 }
 static inline void lim_process_ndi_del_sta_rsp(tpAniSirGlobal mac_ctx,
-				tpSirMsgQ lim_msg, tpPESession pe_session)
+				struct scheduler_msg *lim_msg, tpPESession pe_session)
 {
 }
 
diff --git a/core/mac/src/pe/rrm/rrm_api.c b/core/mac/src/pe/rrm/rrm_api.c
index ceb5a6c..4d9ce2f 100644
--- a/core/mac/src/pe/rrm/rrm_api.c
+++ b/core/mac/src/pe/rrm/rrm_api.c
@@ -151,7 +151,7 @@
 {
 	tpMaxTxPowerParams pMaxTxParams;
 	tSirRetStatus retCode = eSIR_SUCCESS;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 
 	if (pSessionEntry == NULL) {
 		PELOGE(lim_log(pMac, LOGE, FL("Invalid parameters"));)
@@ -210,7 +210,7 @@
  * @param pSessionEntry session entry.
  * @return None
  */
-tSirRetStatus rrm_set_max_tx_power_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ)
+tSirRetStatus rrm_set_max_tx_power_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ)
 {
 	tSirRetStatus retCode = eSIR_SUCCESS;
 	tpMaxTxPowerParams pMaxTxParams = (tpMaxTxPowerParams) limMsgQ->bodyptr;
@@ -352,7 +352,7 @@
 	tpSirNeighborReportInd pSmeNeighborRpt = NULL;
 	uint16_t length;
 	uint8_t i;
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 
 	if (pNeighborRep == NULL || pSessionEntry == NULL) {
 		PELOGE(lim_log(pMac, LOGE, FL(" Invalid parameters"));)
@@ -536,7 +536,7 @@
 			      tDot11fIEMeasurementRequest *pBeaconReq,
 			      tpPESession pSessionEntry)
 {
-	tSirMsgQ mmhMsg;
+	struct scheduler_msg mmhMsg;
 	tpSirBeaconReportReqInd pSmeBcnReportReq;
 	uint8_t num_channels = 0, num_APChanReport;
 	uint16_t measDuration, maxMeasduration;
diff --git a/core/mac/src/pe/sch/sch_api.c b/core/mac/src/pe/sch/sch_api.c
index fd4a48a..8c0be0f 100644
--- a/core/mac/src/pe/sch/sch_api.c
+++ b/core/mac/src/pe/sch/sch_api.c
@@ -128,7 +128,7 @@
  * @return None
  */
 
-tSirRetStatus sch_post_message(tpAniSirGlobal pMac, tpSirMsgQ pMsg)
+tSirRetStatus sch_post_message(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	sch_process_message(pMac, pMsg);
 
@@ -153,7 +153,7 @@
 
 void sch_send_start_scan_rsp(tpAniSirGlobal pMac)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	uint32_t retCode;
 
 	PELOG1(sch_log(pMac, LOG1, FL("Sending LIM message to go into scan"));)
@@ -193,7 +193,7 @@
 tSirRetStatus sch_send_beacon_req(tpAniSirGlobal pMac, uint8_t *beaconPayload,
 				  uint16_t size, tpPESession psessionEntry)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tpSendbeaconParams beaconParams = NULL;
 	tSirRetStatus retCode;
 
@@ -326,7 +326,7 @@
 					    tpPESession psessionEntry,
 					    uint32_t *IeBitmap)
 {
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	uint8_t *pFrame2Hal = psessionEntry->pSchProbeRspTemplate;
 	tpSendProbeRespParams pprobeRespParams = NULL;
 	uint32_t retCode = eSIR_FAILURE;
diff --git a/core/mac/src/pe/sch/sch_beacon_gen.c b/core/mac/src/pe/sch/sch_beacon_gen.c
index 22c5738..73ab740 100644
--- a/core/mac/src/pe/sch/sch_beacon_gen.c
+++ b/core/mac/src/pe/sch/sch_beacon_gen.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -918,7 +918,7 @@
  * @return None
  */
 
-void sch_process_pre_beacon_ind(tpAniSirGlobal pMac, tpSirMsgQ limMsg)
+void sch_process_pre_beacon_ind(tpAniSirGlobal pMac, struct scheduler_msg *limMsg)
 {
 	tpBeaconGenParams pMsg = (tpBeaconGenParams) limMsg->bodyptr;
 	uint32_t beaconSize;
diff --git a/core/mac/src/pe/sch/sch_message.c b/core/mac/src/pe/sch/sch_message.c
index 0208211..7fb44f7 100644
--- a/core/mac/src/pe/sch/sch_message.c
+++ b/core/mac/src/pe/sch/sch_message.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -103,7 +103,7 @@
  * @return None
  */
 
-void sch_process_message(tpAniSirGlobal pMac, tpSirMsgQ pSchMsg)
+void sch_process_message(tpAniSirGlobal pMac, struct scheduler_msg *pSchMsg)
 {
 	uint32_t val;
 
diff --git a/core/mac/src/sys/common/src/wlan_qct_sys.c b/core/mac/src/sys/common/src/wlan_qct_sys.c
index 2244e53..7c02afd 100644
--- a/core/mac/src/sys/common/src/wlan_qct_sys.c
+++ b/core/mac/src/sys/common/src/wlan_qct_sys.c
@@ -272,7 +272,7 @@
  *
  * Return: none
  */
-void sys_process_mmh_msg(tpAniSirGlobal pMac, tSirMsgQ *pMsg)
+void sys_process_mmh_msg(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	QDF_MODULE_ID targetMQ = QDF_MODULE_ID_SYS;
 
diff --git a/core/mac/src/sys/legacy/src/system/inc/sys_startup.h b/core/mac/src/sys/legacy/src/system/inc/sys_startup.h
index e56bd61..586df8c 100644
--- a/core/mac/src/sys/legacy/src/system/inc/sys_startup.h
+++ b/core/mac/src/sys/legacy/src/system/inc/sys_startup.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2014 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2011-2014, 2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -47,7 +47,7 @@
 /* Function */
 
 extern void sysMACCleanup(void *);
-extern tSirRetStatus sys_bbt_process_message_core(struct sAniSirGlobal *, tpSirMsgQ,
+extern tSirRetStatus sys_bbt_process_message_core(struct sAniSirGlobal *, struct scheduler_msg *,
 						  uint32_t, uint32_t);
 
 #endif /* __SYSSTARTUP_H */
diff --git a/core/mac/src/sys/legacy/src/system/src/sys_entry_func.c b/core/mac/src/sys/legacy/src/system/src/sys_entry_func.c
index 1a76045..c022949 100644
--- a/core/mac/src/sys/legacy/src/system/src/sys_entry_func.c
+++ b/core/mac/src/sys/legacy/src/system/src/sys_entry_func.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2016 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2012-2017 The Linux Foundation. All rights reserved.
  *
  * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
  *
@@ -52,7 +52,7 @@
 #include "lim_trace.h"
 #include "wma_types.h"
 
-tSirRetStatus postPTTMsgApi(tpAniSirGlobal pMac, tSirMsgQ *pMsg);
+tSirRetStatus postPTTMsgApi(tpAniSirGlobal pMac, struct scheduler_msg *pMsg);
 
 #include "qdf_types.h"
 #include "cds_packet.h"
@@ -99,7 +99,7 @@
  * Return: None
  */
 tSirRetStatus
-sys_bbt_process_message_core(tpAniSirGlobal mac_ctx, tpSirMsgQ msg,
+sys_bbt_process_message_core(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg,
 		uint32_t type, uint32_t subtype)
 {
 	uint32_t framecount;
diff --git a/core/mac/src/pe/lim/lim_process_message_queue.c b/core/mac/src/pe/lim/lim_process_message_queue.c
index 05e31fd..a11bd71 100644
--- a/core/mac/src/pe/lim/lim_process_message_queue.c
+++ b/core/mac/src/pe/lim/lim_process_message_queue.c
@@ -67,7 +67,7 @@
 
 void lim_log_session_states(tpAniSirGlobal pMac);
 static void lim_process_normal_hdd_msg(tpAniSirGlobal mac_ctx,
-	struct sSirMsgQ *msg, uint8_t rsp_reqd);
+	struct scheduler_msg *msg, uint8_t rsp_reqd);
 
 /**
  * lim_process_dual_mac_cfg_resp() - Process set dual mac config response
@@ -84,7 +84,7 @@
 {
 	struct sir_dual_mac_config_resp *resp, *param;
 	uint32_t len, fail_resp = 0;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	resp = (struct sir_dual_mac_config_resp *)body;
 	if (!resp) {
@@ -139,7 +139,7 @@
 {
 	struct sir_set_hw_mode_resp *resp, *param;
 	uint32_t len, i, fail_resp = 0;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	resp = (struct sir_set_hw_mode_resp *)body;
 	if (!resp) {
@@ -206,7 +206,7 @@
 {
 	struct sir_antenna_mode_resp *resp, *param;
 	bool fail_resp = false;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	resp = (struct sir_antenna_mode_resp *)body;
 	if (!resp) {
@@ -259,7 +259,7 @@
 	struct vdev_ie_info *wma_ie_params;
 	uint8_t *local_ie_buf;
 	uint16_t local_ie_len;
-	tSirMsgQ msg_q;
+	struct scheduler_msg msg_q;
 	tSirRetStatus ret_code;
 
 	if (!msg_buf) {
@@ -323,7 +323,7 @@
 {
 	struct sir_hw_mode_trans_ind *ind, *param;
 	uint32_t len, i;
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 
 	ind = (struct sir_hw_mode_trans_ind *)body;
 	if (!ind) {
@@ -364,12 +364,12 @@
    \fn def_msg_decision
    \brief The function decides whether to defer a message or not in limProcessMessage function
    \param   tpAniSirGlobal pMac
-   \param       tSirMsgQ  limMsg
+   \param       struct scheduler_msg  limMsg
    \param       tSirMacTspecIE   *ppInfo
    \return none
    -------------------------------------------------------------*/
 
-uint8_t static def_msg_decision(tpAniSirGlobal pMac, tpSirMsgQ limMsg)
+uint8_t static def_msg_decision(tpAniSirGlobal pMac, struct scheduler_msg *limMsg)
 {
 
 /* this function should not changed */
@@ -449,7 +449,7 @@
 {
 	struct pno_match_found  *result;
 	uint8_t                 *body;
-	tSirMsgQ                mmh_msg;
+	struct scheduler_msg                mmh_msg;
 	tpSirMacMgmtHdr         hdr;
 	uint32_t num_results = 1, len, i;
 
@@ -507,7 +507,7 @@
 {
 	tpSirWifiFullScanResultEvent result;
 	uint8_t                     *body;
-	tSirMsgQ                     mmh_msg;
+	struct scheduler_msg                     mmh_msg;
 	tpSirMacMgmtHdr              hdr;
 
 	result = qdf_mem_malloc(sizeof(*result) + ie_len);
@@ -619,7 +619,7 @@
  * Not Scanning,
  */
 static void
-__lim_handle_beacon(tpAniSirGlobal pMac, tpSirMsgQ pMsg,
+__lim_handle_beacon(tpAniSirGlobal pMac, struct scheduler_msg *pMsg,
 		    tpPESession psessionEntry)
 {
 	/* checking for global SME state... */
@@ -658,11 +658,11 @@
  * NA
  *
  * @param  pMac - Pointer to Global MAC structure
  * @param  pMsg of type tSirMsgQ - Pointer to the message structure
  * @return None
  */
 
-uint32_t lim_defer_msg(tpAniSirGlobal pMac, tSirMsgQ *pMsg)
+uint32_t lim_defer_msg(tpAniSirGlobal pMac, struct scheduler_msg *pMsg)
 {
 	uint32_t retCode = TX_SUCCESS;
 
@@ -845,12 +845,12 @@
  * NA
  *
  * @param  pMac - Pointer to Global MAC structure
  * @param  pMsg of type tSirMsgQ - Pointer to the message structure
  * @return None
  */
 
 static void
-lim_handle80211_frames(tpAniSirGlobal pMac, tpSirMsgQ limMsg, uint8_t *pDeferMsg)
+lim_handle80211_frames(tpAniSirGlobal pMac, struct scheduler_msg *limMsg, uint8_t *pDeferMsg)
 {
 	uint8_t *pRxPacketInfo = NULL;
 	tSirMacFrameCtl fc;
@@ -1141,7 +1141,7 @@
 static QDF_STATUS lim_send_stop_scan_offload_req(tpAniSirGlobal pMac,
 	uint8_t SessionId, uint32_t scan_id, uint32_t scan_requestor_id)
 {
-	tSirMsgQ msg;
+	struct scheduler_msg msg;
 	tSirRetStatus rc = eSIR_SUCCESS;
 	tAbortScanParams *pAbortScanParams;
 
@@ -1199,7 +1199,7 @@
 }
 
 static void lim_process_sme_obss_scan_ind(tpAniSirGlobal mac_ctx,
-							struct sSirMsgQ *msg)
+							struct scheduler_msg *msg)
 {
 	struct sPESession *session;
 	uint8_t session_id;
@@ -1238,7 +1238,7 @@
  *
  * Return:  None.
  */
-static void lim_process_messages(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
+static void lim_process_messages(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
 #ifdef FEATURE_AP_MCC_CH_AVOIDANCE
 	uint8_t vdev_id = 0;
@@ -1252,7 +1252,7 @@
 	uint16_t pkt_len = 0;
 	cds_pkt_t *body_ptr = NULL;
 	QDF_STATUS qdf_status;
-	tSirMsgQ new_msg;
+	struct scheduler_msg new_msg;
 	tSirSmeScanAbortReq *req_msg = NULL;
 	uint8_t session_id;
 	uint32_t scan_id;
@@ -1348,7 +1348,7 @@
 			break;
 		}
 		qdf_mem_copy((uint8_t *) &new_msg,
-			(uint8_t *) msg, sizeof(tSirMsgQ));
+			(uint8_t *) msg, sizeof(struct scheduler_msg));
 		body_ptr = (cds_pkt_t *) new_msg.bodyptr;
 		cds_pkt_get_packet_length(body_ptr, &pkt_len);
 
@@ -1961,9 +1961,9 @@
 
 static void lim_process_deferred_message_queue(tpAniSirGlobal pMac)
 {
-	tSirMsgQ limMsg = { 0, 0, 0 };
+	struct scheduler_msg limMsg = { 0, 0, 0 };
 
-	tSirMsgQ *readMsg;
+	struct scheduler_msg *readMsg;
 	uint16_t size;
 
 	/*
@@ -1973,7 +1973,7 @@
 	if (size > 0) {
 		while ((readMsg = lim_read_deferred_msg_q(pMac)) != NULL) {
 			qdf_mem_copy((uint8_t *) &limMsg,
-				     (uint8_t *) readMsg, sizeof(tSirMsgQ));
+				     (uint8_t *) readMsg, sizeof(struct scheduler_msg));
 			size--;
 			lim_process_messages(pMac, &limMsg);
 
@@ -1996,7 +1996,7 @@
  *
  * Return:  None.
  */
-void lim_message_processor(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
+void lim_message_processor(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
 	if (eLIM_MLM_OFFLINE_STATE == mac_ctx->lim.gLimMlmState) {
 		pe_free_msg(mac_ctx, msg);
@@ -2024,7 +2024,7 @@
  *
  * Return: None
  */
-static void lim_process_normal_hdd_msg(tpAniSirGlobal mac_ctx, tSirMsgQ *msg,
+static void lim_process_normal_hdd_msg(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg,
 	uint8_t rsp_reqd)
 {
 	bool defer_msg = true;
@@ -658,11 +658,11 @@
  *
  * @param  pMac - Pointer to Global MAC structure
- * @param  pMsg of type tSirMsgQ - Pointer to the message structure
+ * @param  pMsg of type struct scheduler_msg - Pointer to the message structure
  * @return None
  */
@@ -845,12 +845,12 @@
  *
  * @param  pMac - Pointer to Global MAC structure
- * @param  pMsg of type tSirMsgQ - Pointer to the message structure
+ * @param  pMsg of type struct scheduler_msg - Pointer to the message structure
  * @return None
  */
diff --git a/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c b/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
index 4619247..c3ab9fa 100644
--- a/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
+++ b/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
@@ -834,7 +834,7 @@
 void lim_process_mlm_assoc_ind(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
 {
 	uint32_t len;
-	tSirMsgQ msgQ;
+	struct scheduler_msg msgQ;
 	tSirSmeAssocInd *pSirSmeAssocInd;
 	tpDphHashNode pStaDs = 0;
 	tpPESession psessionEntry;
@@ -1432,11 +1432,11 @@
  ***NOTE:
  *
  * @param  pMac      Pointer to Global MAC structure
  * @param  tSirMsgQ  The MsgQ header, which contains the response buffer
  *
  * @return None
  */
-void lim_process_mlm_add_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_mlm_add_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				 tpPESession psessionEntry)
 {
 	/* we need to process the deferred message since the initiating req. there might be nested request. */
@@ -1453,7 +1453,7 @@
 /**
  * lim_process_sta_mlm_add_sta_rsp () - Process add sta response
  * @mac_ctx:  Pointer to mac context
  * @msg:  tpSirMsgQan Message structure
  * @session_entry: PE session entry
  *
  * Process ADD STA response sent from WMA and posts results
@@ -1463,7 +1463,7 @@
  */
 
 void lim_process_sta_mlm_add_sta_rsp(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg, tpPESession session_entry)
+	struct scheduler_msg *msg, tpPESession session_entry)
 {
 	tLimMlmAssocCnf mlm_assoc_cnf;
 	tpDphHashNode sta_ds;
@@ -1597,7 +1597,7 @@
 	return;
 }
 
-void lim_process_mlm_del_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_mlm_del_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				 tpPESession psessionEntry)
 {
 	/* we need to process the deferred message since the initiating req. there might be nested request. */
@@ -1625,7 +1625,7 @@
 #endif
 }
 
-void lim_process_sta_mlm_del_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_sta_mlm_del_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				     tpPESession psessionEntry)
 {
 	tpDeleteBssParams pDelBssParams = (tpDeleteBssParams) limMsgQ->bodyptr;
@@ -1703,7 +1703,7 @@
 	return;
 }
 
-void lim_process_ap_mlm_del_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_ap_mlm_del_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 					   tpPESession psessionEntry)
 {
 	tSirResultCodes rc = eSIR_SME_SUCCESS;
@@ -1780,7 +1780,7 @@
  * Return: None
  */
 void lim_process_mlm_del_sta_rsp(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg)
+	struct scheduler_msg *msg)
 {
 	/*
 	 * we need to process the deferred message since the
@@ -1832,7 +1832,7 @@
  * Retunrn: None
  */
 void lim_process_ap_mlm_del_sta_rsp(tpAniSirGlobal mac_ctx,
-					   tpSirMsgQ msg,
+					   struct scheduler_msg *msg,
 					   tpPESession session_entry)
 {
 	tpDeleteStaParams del_sta_params = (tpDeleteStaParams) msg->bodyptr;
@@ -1926,7 +1926,7 @@
 	return;
 }
 
-void lim_process_sta_mlm_del_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_sta_mlm_del_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				     tpPESession psessionEntry)
 {
 	tSirResultCodes statusCode = eSIR_SME_SUCCESS;
@@ -1981,7 +1981,7 @@
 	return;
 }
 
-void lim_process_ap_mlm_add_sta_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+void lim_process_ap_mlm_add_sta_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 					   tpPESession psessionEntry)
 {
 	tpAddStaParams pAddStaParams = (tpAddStaParams) limMsgQ->bodyptr;
@@ -2003,7 +2003,7 @@
 	}
 	/* */
 	/* TODO & FIXME_GEN4 */
 	/* Need to inspect tSirMsgQ.reserved for a valid Dialog token! */
 	/* */
 	/* TODO: any check for pMac->lim.gLimMlmState ? */
 	if (eLIM_MLM_WT_ADD_STA_RSP_STATE != pStaDs->mlmStaContext.mlmState) {
@@ -2077,17 +2077,17 @@
  * LIM responds with eWNI_SME_START_BSS_RSP to SME
  *
  ***ASSUMPTIONS:
  * tSirMsgQ.body is allocated by MLME during lim_process_mlm_start_req
  * tSirMsgQ.body will now be freed by this routine
  *
  ***NOTE:
  *
  * @param  pMac      Pointer to Global MAC structure
  * @param  tSirMsgQ  The MsgQ header, which contains the response buffer
  *
  * @return None
  */
-static void lim_process_ap_mlm_add_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ)
+static void lim_process_ap_mlm_add_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ)
 {
 	tLimMlmStartCnf mlmStartCnf;
 	tpPESession psessionEntry;
@@ -2224,18 +2224,18 @@
  * LIM responds with eWNI_SME_START_BSS_RSP to SME
  *
  ***ASSUMPTIONS:
  * tSirMsgQ.body is allocated by MLME during lim_process_mlm_start_req
  * tSirMsgQ.body will now be freed by this routine
  *
  ***NOTE:
  *
  * @param  pMac      Pointer to Global MAC structure
  * @param  tSirMsgQ  The MsgQ header, which contains the response buffer
  *
  * @return None
  */
 static void
-lim_process_ibss_mlm_add_bss_rsp(tpAniSirGlobal pMac, tpSirMsgQ limMsgQ,
+lim_process_ibss_mlm_add_bss_rsp(tpAniSirGlobal pMac, struct scheduler_msg *limMsgQ,
 				 tpPESession psessionEntry)
 {
 	tLimMlmStartCnf mlmStartCnf;
@@ -2313,7 +2313,7 @@
  */
 static void
 lim_process_sta_add_bss_rsp_pre_assoc(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg, tpPESession session_entry)
+	struct scheduler_msg *msg, tpPESession session_entry)
 {
 	tpAddBssParams pAddBssParams = (tpAddBssParams) msg->bodyptr;
 	tAniAuthType cfgAuthType, authMode;
@@ -2429,14 +2429,14 @@
  * HAL responded with WMA_ADD_BSS_RSP to MLME
  * MLME now sends WMA_ADD_STA_REQ to HAL
  * ASSUMPTIONS:
  * tSirMsgQ.body is allocated by MLME during lim_process_mlm_join_req
  * tSirMsgQ.body will now be freed by this routine
  *
  * Return: None
  */
 static void
 lim_process_sta_mlm_add_bss_rsp(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg, tpPESession session_entry)
+	struct scheduler_msg *msg, tpPESession session_entry)
 {
 	tpAddBssParams add_bss_params = (tpAddBssParams) msg->bodyptr;
 	tLimMlmAssocCnf mlm_assoc_cnf;
@@ -2605,7 +2605,7 @@
  * Return None
  */
 void lim_process_mlm_add_bss_rsp(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg)
+	struct scheduler_msg *msg)
 {
 	tLimMlmStartCnf mlm_start_cnf;
 	tpPESession session_entry;
@@ -2715,7 +2715,7 @@
  * Return: None
  */
 void lim_process_mlm_set_sta_key_rsp(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg)
+	struct scheduler_msg *msg)
 {
 	uint8_t resp_reqd = 1;
 	tLimMlmSetKeysCnf mlm_set_key_cnf;
@@ -2798,7 +2798,7 @@
  * Return: NULL
  */
 void lim_process_mlm_set_bss_key_rsp(tpAniSirGlobal mac_ctx,
-	tpSirMsgQ msg)
+	struct scheduler_msg *msg)
 {
 	tLimMlmSetKeysCnf set_key_cnf;
 	uint16_t result_status;
@@ -3216,7 +3216,7 @@
 void lim_send_beacon_ind(tpAniSirGlobal pMac, tpPESession psessionEntry)
 {
 	tBeaconGenParams *pBeaconGenParams = NULL;
-	tSirMsgQ limMsg;
+	struct scheduler_msg limMsg;
 	/** Allocate the Memory for Beacon Pre Message and for Stations in PoweSave*/
 	if (psessionEntry == NULL) {
 		PELOGE(lim_log(pMac, LOGE,
@@ -1432,11 +1432,11 @@
  *
  * @param  pMac      Pointer to Global MAC structure
- * @param  tSirMsgQ  The MsgQ header, which contains the response buffer
+ * @param  struct scheduler_msg  The MsgQ header, which contains the response buffer
  *
  * @return None
@@ -1453,7 +1453,7 @@
  * lim_process_sta_mlm_add_sta_rsp () - Process add sta response
  * @mac_ctx:  Pointer to mac context
- * @msg:  tpSirMsgQan Message structure
+ * @msg:  struct scheduler_msg *an Message structure
  * @session_entry: PE session entry
  *
@@ -2003,7 +2003,7 @@
 	/* */
 	/* TODO & FIXME_GEN4 */
-	/* Need to inspect tSirMsgQ.reserved for a valid Dialog token! */
+	/* Need to inspect struct scheduler_msg.reserved for a valid Dialog token! */
 	/* */
 	/* TODO: any check for pMac->lim.gLimMlmState ? */
@@ -2077,17 +2077,17 @@
  *
  ***ASSUMPTIONS:
- * tSirMsgQ.body is allocated by MLME during lim_process_mlm_start_req
- * tSirMsgQ.body will now be freed by this routine
+ * struct scheduler_msg.body is allocated by MLME during lim_process_mlm_start_req
+ * struct scheduler_msg.body will now be freed by this routine
  *
  ***NOTE:
@@ -2077,17 +2077,17 @@
  *
  * @param  pMac      Pointer to Global MAC structure
- * @param  tSirMsgQ  The MsgQ header, which contains the response buffer
+ * @param  struct scheduler_msg  The MsgQ header, which contains the response buffer
  *
  * @return None
@@ -2224,18 +2224,18 @@
  *
  ***ASSUMPTIONS:
- * tSirMsgQ.body is allocated by MLME during lim_process_mlm_start_req
- * tSirMsgQ.body will now be freed by this routine
+ * struct scheduler_msg.body is allocated by MLME during lim_process_mlm_start_req
+ * struct scheduler_msg.body will now be freed by this routine
  *
  ***NOTE:
@@ -2224,18 +2224,18 @@
  *
  * @param  pMac      Pointer to Global MAC structure
- * @param  tSirMsgQ  The MsgQ header, which contains the response buffer
+ * @param  struct scheduler_msg  The MsgQ header, which contains the response buffer
  *
  * @return None
@@ -2429,14 +2429,14 @@
  * MLME now sends WMA_ADD_STA_REQ to HAL
  * ASSUMPTIONS:
- * tSirMsgQ.body is allocated by MLME during lim_process_mlm_join_req
- * tSirMsgQ.body will now be freed by this routine
+ * struct scheduler_msg.body is allocated by MLME during lim_process_mlm_join_req
+ * struct scheduler_msg.body will now be freed by this routine
  *
  * Return: None